# Fact Sheet Subscription
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription#introduction)
  * [Subscription Type](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription#subscription-type)
  * [Subscription Role](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription#subscription-role)
  * [Difference between Subscription Roles and User Roles](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription#difference-between-subscription-roles-and-user-roles)
  * [Subscribing to Fact Sheets](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription#subscribing-to-fact-sheets)
  * [Adding Non-SAP-LeanIX Users as Subscribers](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription#adding-non-sap-leanix-users-as-subscribers)
  * [Modifying Subscription Details](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription#modifying-subscription-details)
  * [Unsubscribing from Fact Sheets](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription#unsubscribing-from-fact-sheets)


View all
Fact sheet subscription assigns responsibility and accountability to users for maintaining data. Learn about fact sheet subscriptions, including types, roles, and how to assign and subscribe to fact sheets to promote stakeholder involvement and ensure data accuracy and completeness.
